@@ -162,9 +162,7 @@ class _MLP(nn.Module):
 
 
 class MLP(BaseNet):
-    """Multi-layer perceptron with identical # of hidden units.
 
-    """
     def __init__(
         self,
         dims : Union[int, Tuple[int]],
@@ -259,16 +257,7 @@ class MLP(BaseNet):
 
 
 class _ContractingMLP(nn.Module):
-    """ContractingMLP with given contraction ratio.
 
-    _ContractingMLP and ContractingMLP defines an MLP with number of hidden units decreasing with a factor
-    of contraction_ratio.
-    Therefore, the hyperparameter that is additionally defined in ContractingMLP is contraction_ratio.
-
-    _ContractingMLP and ContractingMLP are basically identical in structure. The only difference is that
-    _ContractingMLP is an offspring of nn.Module and ContractingMLP is an offspring of BaseNet.
-
-    """
     def __init__(
         self,
         dims : Union[int, Tuple[int]],
@@ -286,8 +275,8 @@ class _ContractingMLP(nn.Module):
         momentum : float=0.9,
         negative_slope : Optional[float] = None,
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None
-    ) -> None:
-        """Initialize ContractingMLP
+    )->None:
+        """ContractingMLP
         
         Args:
         
@@ -316,7 +305,7 @@ class _ContractingMLP(nn.Module):
             lr (float): Learning rate. 
                 Default: ``1e-4``
                     
-    """
+        """
         super(_ContractingMLP, self).__init__()
 
         if not isinstance(dims, int):
@@ -481,7 +470,7 @@ class ContractingMLP(BaseNet):
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None,
         scheduler_config: Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         **hparams : Any
-    ) -> None:
+    )->None:
         """Initialize ContractingMLP
         
         Args:
